From b7df88319847f3155bd0e2ea994cf66c01fc1732 Mon Sep 17 00:00:00 2001
From: Mart Raudsepp <leio@gentoo.org>
Date: Sat, 23 Feb 2019 12:21:01 +0200
Subject: [PATCH] build: Provide introspection option and don't build manual
 tests

---
 libgweather/meson.build | 21 ++++++++++++++-------
 meson.build             |  4 ++++
 meson_options.txt       |  2 ++
 3 files changed, 20 insertions(+), 7 deletions(-)

diff --git a/libgweather/meson.build b/libgweather/meson.build
index 4d907b9..9ede9d0 100644
--- a/libgweather/meson.build
+++ b/libgweather/meson.build
@@ -65,6 +65,15 @@ lib_libgweather = shared_library('gweather-3',
   install: true,
 )
 
+libgweather_dep = declare_dependency(
+  sources: [gweather_enum_types[1]],
+  dependencies: deps_libgweather,
+  link_with: lib_libgweather,
+  include_directories: root_inc,
+)
+
+if get_option('introspection')
+
 gweather_gir = gnome.generate_gir(lib_libgweather,
   sources: introspection_sources,
   dependencies: deps_libgweather,
@@ -79,13 +88,6 @@ gweather_gir = gnome.generate_gir(lib_libgweather,
   install: true,
 )
 
-libgweather_dep = declare_dependency(
-  sources: [gweather_enum_types[1], gweather_gir],
-  dependencies: deps_libgweather,
-  link_with: lib_libgweather,
-  include_directories: root_inc,
-)
-
 if enable_vala
   gnome.generate_vapi('gweather-3.0',
     sources: gweather_gir[0],
@@ -94,9 +96,11 @@ if enable_vala
     install: true
   )
 endif
+endif
 
 test_cargs = ['-DTEST_SRCDIR="@0@/"'.format(meson.current_source_dir())]
 
+if false
 executable('test_locations',
   ['test_locations.c'],
   c_args: test_cargs,
@@ -107,6 +111,7 @@ executable('test_locations_utc',
   c_args: test_cargs,
   dependencies: libgweather_dep,
   install: false)
+endif
 
 exe = executable('test_libgweather',
   ['test_libgweather.c'],
@@ -115,6 +120,7 @@ exe = executable('test_libgweather',
   install: false)
 test('test_named_timezones', exe)
 
+if false
 executable('test_metar',
   ['test_metar.c', gweather_c_sources],
   c_args: test_cargs,
@@ -125,3 +131,4 @@ executable('test_sun_moon',
   c_args: test_cargs,
   dependencies: libgweather_dep,
   install: false)
+endif
diff --git a/meson.build b/meson.build
index 5b30864..2e9fa08 100644
--- a/meson.build
+++ b/meson.build
@@ -108,6 +108,10 @@ else
   enable_vala = enable_vala != 'false'
 endif
 
+if enable_vala and not get_option('introspection')
+  error('Vala bindings require introspection support')
+endif
+
 root_inc = include_directories('.')
 
 subdir('libgweather')
diff --git a/meson_options.txt b/meson_options.txt
index 19b2c6a..bf4c517 100644
--- a/meson_options.txt
+++ b/meson_options.txt
@@ -8,3 +8,5 @@ option('enable_vala', type: 'combo', choices : ['true', 'false', 'auto'], value
        description: 'Install vala bindings')
 option('gtk_doc', type: 'boolean', value: false,
        description: 'Whether to generate the API reference')
+option('introspection', type: 'boolean', value: true,
+       description: 'generate GObject Introspection data')
-- 
2.17.0

